@@ -3,5 +3,5 @@ Log <- function(x, na.rm = FALSE) {
 	if(na.rm){
 		x <- x[-is.na(x)]
 	}
-  	.Call('Rfast_Log',x)
+  	.Call(Rfast_Log,x)
 }
\ No newline at end of file
