@@ -4,8 +4,8 @@ Order<-function(x,stable=FALSE,descending=FALSE,partial=NULL){
 		x <- as.numeric(x)
 	}
 	if(is.null(partial)){
-		.Call("Rfast_Order",x,stable,descending)
+		.Call(Rfast_Order,x,stable,descending)
 	}else{
-		.Call('Rfast_partial_sort_index',PACKAGE = "Rfast",x,partial,descending)
+		.Call(Rfast_partial_sort_index,x,partial,descending)
 	}
 }
\ No newline at end of file
