@@ -1,7 +1,7 @@
 cqtest <- function(x, treat, block, logged = FALSE) {
-  k <- sort_unique.length(treat)
-  cj <- group.sum(x, treat)
-  ri <- group.sum(x, block)  
+  k <- Rfast::sort_unique.length(treat)
+  cj <- Rfast::group.sum(x, treat)
+  ri <- Rfast::group.sum(x, block)  
   N <- sum(cj)
   up <- k * (k - 1) * sum(cj^2) - (k - 1) * N^2
   stat <- up / (k * N - sum(ri^2) )
