@@ -1,7 +1,7 @@
 
 data.frame.to_matrix <- function(x,col.names = NULL,row.names = NULL) {
 	if(is.null(col.names) && is.null(row.names)){
-		x <- .Call('Rfast_frame_to_matrix', PACKAGE = 'Rfast',x)
+		x <- .Call(Rfast_frame_to_matrix,x)
 	}else{
 		if(col.names == TRUE){
 			col.names <- colnames(x)
@@ -9,7 +9,7 @@ data.frame.to_matrix <- function(x,col.names = NULL,row.names = NULL) {
 		if(row.names == TRUE){
 			row.names <- rownames(x)
 		}
-		x <- .Call('Rfast_frame_to_matrix', PACKAGE = 'Rfast',x)
+		x <- .Call(Rfast_frame_to_matrix,x)
 		colnames(x) <- col.names
 		rownames(x) <- row.names
 	}
