@@ -1,4 +1,4 @@
 
 eachcol.apply<-function(x,y,indices = NULL,oper = "*",apply = "sum"){
-	.Call('Rfast_eachcol_apply',PACKAGE = "Rfast",x,y,indices,oper,apply)
+	.Call(Rfast_eachcol_apply,x,y,indices,oper,apply)
 }
\ No newline at end of file
