@@ -1,4 +1,4 @@
 
 hash.list <- function(key,x) {
-  .Call('Rfast_Hash_list',key,x)
+  .Call(Rfast_Hash_list,key,x)
 }
\ No newline at end of file
