@@ -1,6 +1,6 @@
 qpois.reg <- function (x, y, full = FALSE, tol = 1e-09, maxiters = 100) {
     x <- model.matrix(y ~ ., data.frame(x))
-    mod <- .Call("Rfast_qpois_reg",PACKAGE = "Rfast", x, y, sum(y * log(y), na.rm = TRUE), 
+    mod <- .Call(Rfast_qpois_reg, x, y, sum(y * log(y), na.rm = TRUE), 
         tol,maxiters)
     res <- list(be = mod$be, devi = mod$deviance, varb = mod$phi * 
         spdinv(mod$L2), phi = mod$phi)
