@@ -1,7 +1,8 @@
 
 #include <vector>
 #include <stack>
-#include "mn.h"
+#include <RcppArmadillo.h>
+//#include "mn.h"
 
 using namespace Rcpp;
 
@@ -52,8 +53,7 @@ IntegerVector topological_sort(IntegerMatrix dag) {
 }
 
 
-//[[Rcpp::export]]
-IntegerVector topological_sort2(IntegerMatrix dag) {
+static IntegerVector topological_sort2(IntegerMatrix dag) {
     const int n = dag.nrow();
     IntegerVector indeg = colSums(dag(Range(0,n-1),Range(0,n-1)));
     vector<int> cs,zero_indeg; // a stack of nodes with no parents
