@@ -17,7 +17,7 @@ List weibull_mle(NumericVector X, const double tol, const int maxiters){
 
   while (++i<maxiters && sum(abs(b2 - b1)) > tol) {
     b1 = b2;
-    y = my_pow2(x,y,b1,n);
+    my_pow2(x,&y[0],b1,n);
     co = sum(y % lx);
     sy = sum(y);
     fb = 1/b1 + mlx - co/sy;
@@ -28,7 +28,8 @@ List weibull_mle(NumericVector X, const double tol, const int maxiters){
 
   l["iters"] = i-1;
   double theta = pow(sy/n,1/b2);
-  l["loglik"] = n * log(b2) - n * b2 * log(theta) + (b2 - 1) * n * mlx - sum(my_pow2(conv_to<vec>::from(x/theta),y,b2,n));
+  my_pow2(conv_to<vec>::from(x/theta),&y[0],b2,n);
+  l["loglik"] = n * log(b2) - n * b2 * log(theta) + (b2 - 1) * n * mlx - sum(y);
   vec param(2);
   param[0] = b2;
   param[1] = theta;
@@ -38,7 +39,6 @@ List weibull_mle(NumericVector X, const double tol, const int maxiters){
   return l;
 }
 
-
 RcppExport SEXP Rfast_weibull_mle(SEXP XSEXP,SEXP tolSEXP,SEXP maxitersSEXP) {
 BEGIN_RCPP
     RObject __result;
